import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { BatchGetMetricsRequest, BatchGetMetricsResponse } from "../models/models_0";
import { SageMakerMetricsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerMetricsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link BatchGetMetricsCommand}.
 */
export interface BatchGetMetricsCommandInput extends BatchGetMetricsRequest {
}
/**
 * @public
 *
 * The output of {@link BatchGetMetricsCommand}.
 */
export interface BatchGetMetricsCommandOutput extends BatchGetMetricsResponse, __MetadataBearer {
}
declare const BatchGetMetricsCommand_base: {
    new (input: BatchGetMetricsCommandInput): import("@smithy/smithy-client").CommandImpl<BatchGetMetricsCommandInput, BatchGetMetricsCommandOutput, SageMakerMetricsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: BatchGetMetricsCommandInput): import("@smithy/smithy-client").CommandImpl<BatchGetMetricsCommandInput, BatchGetMetricsCommandOutput, SageMakerMetricsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Used to retrieve training metrics from SageMaker.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerMetricsClient, BatchGetMetricsCommand } from "@aws-sdk/client-sagemaker-metrics"; // ES Modules import
 * // const { SageMakerMetricsClient, BatchGetMetricsCommand } = require("@aws-sdk/client-sagemaker-metrics"); // CommonJS import
 * const client = new SageMakerMetricsClient(config);
 * const input = { // BatchGetMetricsRequest
 *   MetricQueries: [ // MetricQueryList // required
 *     { // MetricQuery
 *       MetricName: "STRING_VALUE", // required
 *       ResourceArn: "STRING_VALUE", // required
 *       MetricStat: "Min" || "Max" || "Avg" || "Count" || "StdDev" || "Last", // required
 *       Period: "OneMinute" || "FiveMinute" || "OneHour" || "IterationNumber", // required
 *       XAxisType: "IterationNumber" || "Timestamp", // required
 *       Start: Number("long"),
 *       End: Number("long"),
 *     },
 *   ],
 * };
 * const command = new BatchGetMetricsCommand(input);
 * const response = await client.send(command);
 * // { // BatchGetMetricsResponse
 * //   MetricQueryResults: [ // MetricQueryResultList
 * //     { // MetricQueryResult
 * //       Status: "Complete" || "Truncated" || "InternalError" || "ValidationError", // required
 * //       Message: "STRING_VALUE",
 * //       XAxisValues: [ // XAxisValues // required
 * //         Number("long"),
 * //       ],
 * //       MetricValues: [ // MetricValues // required
 * //         Number("double"),
 * //       ],
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param BatchGetMetricsCommandInput - {@link BatchGetMetricsCommandInput}
 * @returns {@link BatchGetMetricsCommandOutput}
 * @see {@link BatchGetMetricsCommandInput} for command's `input` shape.
 * @see {@link BatchGetMetricsCommandOutput} for command's `response` shape.
 * @see {@link SageMakerMetricsClientResolvedConfig | config} for SageMakerMetricsClient's `config` shape.
 *
 * @throws {@link SageMakerMetricsServiceException}
 * <p>Base exception class for all service exceptions from SageMakerMetrics service.</p>
 *
 * @public
 */
export declare class BatchGetMetricsCommand extends BatchGetMetricsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: BatchGetMetricsRequest;
            output: BatchGetMetricsResponse;
        };
        sdk: {
            input: BatchGetMetricsCommandInput;
            output: BatchGetMetricsCommandOutput;
        };
    };
}
